ChopperRequestLog class

Constructors

ChopperRequestLog(String? message, {required BaseRequest request, required TalkerChopperLoggerSettings settings})

Properties

error → Error?
Error? error - error if it happened
finalinherited
exception → Object?
Exception? exception - exception if it happened
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
key → String
no setter
logLevel → LogLevel
LogLevel logLevel - to control logging output
no setter
message → String?
String message - message describes what happened
finalinherited
pen ↔ AnsiPen
AnsiPen? pen - sets your own log color for console
getter/setter pairinherited-setter
request → BaseRequest
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
settings → TalkerChopperLoggerSettings
final
stackTrace → StackTrace?
StackTrace?] stackTrace - stackTrace if exception or error happened
finalinherited
time → DateTime
Internal time when the log occurred
no setterinherited
title ↔ String?
Title of Talker log
getter/setter pairinherited

Methods

convert(Object? object) → String
generateTextMessage({TimeFormat timeFormat = TimeFormat.timeAndSeconds}) → String
Internal method that generates a complete message about the event
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited